# Related Resources

Here are some resources related to the Jupyter Enterprise Gateway project.

- [Jupyter.org](https://jupyter.org)
- [Jupyter Server Team Compass](https://github.com/jupyter-server/team-compass#jupyter-server-team-compass)
- [Jupyter Calendar - Community Meetings](https://docs.jupyter.org/en/latest/community/content-community.html#jupyter-community-meetings)
- [Jupyter Community Discourse Forum](https://discourse.jupyter.org/)
- [Jupyter Enterprise Gateway Github Repo](https://github.com/jupyter-server/enterprise_gateway) - the source code for Enterprise Gateway - which supports remote kernels using Process Proxies. It's 4.0 release will support kernel provisioners and process proxy support will go away.
- [Jupyter Kernel Gateway Github Repo](https://github.com/jupyter-server/kernel_gateway) - the source code for Kernel Gateway - which immediately supports kernel provisioners by virtue of using the base `KernelManager` class.
- [Jupyter Server Github Repo](https://github.com/jupyter-server/jupyter_server) - the source code for the Jupyter Server.
- [Jupyter Client Github Repo](https://github.com/jupyter/jupyter_client) - the source code for the base kernel lifecycle management and message classes. Enterprise Gateway extends the `KernelManager` classes of `jupyter_client`.
